@@ -4,8 +4,8 @@ package inc::MBX::Alien::FLTK::Platform::Unix::Solaris;
     use warnings;
     use Carp qw[];
     use Config qw[%Config];
-    use lib '../../../../../../';
-    use inc::MBX::Alien::FLTK::Utility qw[_o _a _rel _abs can_run];
+    use inc::MBX::Alien::FLTK::Utility
+        qw[_o _a _rel _abs find_h find_lib can_run];
     use inc::MBX::Alien::FLTK;
     use base 'inc::MBX::Alien::FLTK::Platform::Unix';
     $|++;
@@ -13,30 +13,11 @@ package inc::MBX::Alien::FLTK::Platform::Unix::Solaris;
     sub configure {
         my ($self) = @_;
         $self->SUPER::configure() || return 0;    # Get basic config data
-
-        # cpantesters.org/cpan/report/07134937-b19f-3f77-b713-d32bba55d77f
-        $self->notes('define')->{'HAVE_SCANDIR'}    # STR #1890
-            = $self->notes('os_ver') =~ '510' ? 1 : 0;    # 5.10 has scandir
+        print "Gathering Solaris specific configuration data...\n";
+        print "(Not using scandir emulation function.)\n";
+        $self->notes('config')->{'HAVE_SCANDIR'} = undef;
         return 1;
     }
-
-    sub _configure_ar {
-        my $s = shift;
-        print 'Locating library archiver... ';
-        open(my ($OLDOUT), ">&STDOUT");
-        close *STDOUT;
-        my ($ar) = grep { defined $_ } can_run($Config{'gar'}),
-            can_run($Config{'ar'});
-        open(*STDOUT, '>&', $OLDOUT)
-            || exit !print "Couldn't restore STDOUT: $!\n";
-        if (!$ar) {
-            print "Could not find the library archiver, aborting.\n";
-            exit 0;
-        }
-        $ar .= ' -r -c' . (can_run($Config{'ranlib'}) ? ' -s' : '');
-        $s->notes(AR => $ar);
-        print "$ar\n";
-    }
     1;
 }
 
@@ -62,6 +43,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Solaris.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
+=for git $Id: Solaris.pm dc42150 2010-01-17 03:51:57Z sanko@cpan.org $
 
 =cut
